changeset 99455:de3c8bf4f808

(command-line): Ignore init-file-user when checking user's home directory on MS-DOS as well.
author Eli Zaretskii <eliz@gnu.org>
date Sat, 08 Nov 2008 13:15:06 +0000
parents 05580ce7beab
children 9914da365db0
files lisp/startup.el
diffstat 1 files changed, 9 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/startup.el	Sat Nov 08 13:02:38 2008 +0000
+++ b/lisp/startup.el	Sat Nov 08 13:15:06 2008 +0000
@@ -977,13 +977,15 @@
 				   init-file-user)
 			   :error)
 	(if (file-directory-p (expand-file-name
-			       ;; We don't support ~USER on MS-Windows except
-			       ;; for the current user, and always load .emacs
-			       ;; from the current user's home directory (see
-			       ;; below).  So always check "~", even if invoked
-			       ;; with "-u USER", or if $USER or $LOGNAME are
-			       ;; set to something different.
-			       (if (eq system-type 'windows-nt)
+			       ;; We don't support ~USER on MS-Windows
+			       ;; and MS-DOS except for the current
+			       ;; user, and always load .emacs from
+			       ;; the current user's home directory
+			       ;; (see below).  So always check "~",
+			       ;; even if invoked with "-u USER", or
+			       ;; if $USER or $LOGNAME are set to
+			       ;; something different.
+			       (if (memq system-type '(windows-nt ms-dos))
 				   "~"
 				 (concat "~" init-file-user))))
 	    nil